/// <reference types="node" />
import { AsyncCompleter, Completer, ReadLine as ReadLineBase } from 'readline';
interface ReadLine extends ReadLineBase {
    output: NodeJS.WritableStream;
    _refreshLine(): void;
}
export declare class BRLInterface {
    private stdout;
    private stderr;
    readonly readline: ReadLine;
    readonly wrappedStdout: NodeJS.WritableStream;
    readonly wrappedStderr: NodeJS.WritableStream;
    readonly wrappedConsole: Console;
    private state;
    private stdoutPD;
    private stderrPD;
    private consolePD;
    private console;
    constructor(stdout?: NodeJS.WritableStream, stderr?: NodeJS.WritableStream, stdin?: NodeJS.ReadableStream, completer?: Completer | AsyncCompleter | undefined);
    private wrapWritable;
    setPrompt(prompt: string): void;
    onLine(cb: (line: string) => void): void;
    prompt(): void;
    promptLoop(cb?: (line: string) => void): void;
    /**
     * Start replacing `process.stdout`, `process.stderr` and `console` with
     * their wrapped version
     */
    start(): void;
    /**
     * Makes the replaced `process.stdout`, `process.stderr` and `console`
     * return their initial value until {@link resume} is called. This doesn't
     * reset the replaced properties, it just turns a flag on
     */
    pause(): void;
    /**
     * @see {@link pause}
     */
    resume(): void;
    /**
     * Completely reset `process.stdout`, `process.stderr` and `console` to
     * their original property descriptors
     */
    stop(): void;
}
export declare function createInterface(input?: NodeJS.ReadableStream, output?: NodeJS.WritableStream, completer?: Completer | AsyncCompleter): ReadLine;
export declare enum InterfaceState {
    STARTED = 0,
    PAUSED = 1,
    STOPPED = 2
}
export {};
